pub trait MacAddrBytes {
// Required methods
fn to_array(&self) -> [u8; 6];
fn as_array(&self) -> &[u8; 6];
}Expand description
This trait aims to add some friction to convert a type into MacAddrBytes. The purpose being that function using the types implementing this trait, e.g. MacAddr, should prefer not accessing the MacAddrBytes directly when possible.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".